"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var react_router_dom_1 = require("react-router-dom");
var util_1 = require("../../util");
var di_1 = require("../../di");
var definition_1 = require("../../definition");
var root_1 = require("../root");
var message_1 = require("../message");
var universal_application_container_1 = require("./universal-application.container");
var ApplicationContainer = /** @class */ (function (_super) {
    __extends(ApplicationContainer, _super);
    function ApplicationContainer() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.routerRef = React.createRef();
        return _this;
    }
    /**
     * @stable [24.09.2019]
     * @returns {JSX.Element}
     */
    ApplicationContainer.prototype.render = function () {
        return (React.createElement(react_router_dom_1.BrowserRouter, { ref: this.routerRef, basename: this.props.basename || this.environment.basePath },
            React.createElement(react_router_dom_1.Switch, null, this.getRoutes())));
    };
    /**
     * @stable [24.09.2019]
     */
    ApplicationContainer.prototype.componentDidMount = function () {
        di_1.bindToConstantValue(di_1.DI_TYPES.Router, this.dynamicRouter);
        _super.prototype.componentDidMount.call(this);
    };
    // TODO refactoring
    ApplicationContainer.prototype.getRoutes = function () {
        var props = this.props;
        return this.isMessageVisible()
            ? [
                React.createElement(message_1.Message, { key: util_1.uuid(), className: 'rac-application-message', error: props.error, progress: props.progress, errorMessage: this.getErrorMessage(), emptyMessage: this.settings.messages.appNotReadyMessage })
            ]
            : _super.prototype.getRoutes.call(this);
    };
    /**
     * @stable [16.11.2019]
     * @param {IContainerCtor} ctor
     * @param {IConnectorEntity} connectorEntity
     * @returns {JSX.Element}
     */
    ApplicationContainer.prototype.buildRoute = function (ctor, connectorEntity) {
        var routeEntity = connectorEntity.routeConfiguration;
        var Component = routeEntity.type === definition_1.ContainerVisibilityTypesEnum.PRIVATE
            ? root_1.PrivateRootContainer
            : root_1.PublicRootContainer;
        return (React.createElement(Component, __assign({ exact: true, accessConfiguration: connectorEntity.accessConfiguration, container: ctor }, routeEntity, { key: routeEntity.path || routeEntity.key })));
    };
    /**
     * @stable [24.09.2019]
     * @returns {boolean}
     */
    ApplicationContainer.prototype.registerStateTask = function () {
        var result = _super.prototype.registerStateTask.call(this);
        if (result) {
            this.stateUnloadUnsubscriber =
                this.eventManager.subscribe(this.environment.window, definition_1.EventsEnum.UNLOAD, this.syncState);
        }
        return result;
    };
    /**
     * @stable [24.09.2019]
     * @returns {boolean}
     */
    ApplicationContainer.prototype.unregisterStateTask = function () {
        var result = _super.prototype.unregisterStateTask.call(this);
        if (result && util_1.isFn(this.stateUnloadUnsubscriber)) {
            this.stateUnloadUnsubscriber();
        }
        return result;
    };
    Object.defineProperty(ApplicationContainer.prototype, "dynamicRouter", {
        /**
         * @stable [24.09.2019]
         * @returns {IRouter}
         */
        get: function () {
            // We cannot to get access to history instance other way. This instance is private
            return this.routerRef.current.history;
        },
        enumerable: true,
        configurable: true
    });
    return ApplicationContainer;
}(universal_application_container_1.UniversalApplicationContainer));
exports.ApplicationContainer = ApplicationContainer;
//# sourceMappingURL=application.container.js.map