/// <reference types="react" />
import { IConnectorEntity, IContainerCtor, RoutePredicateT } from '../../definition';
import { IUniversalApplicationContainerProps } from './universal-application.interface';
import { UniversalContainer } from '../base/universal.container';
export declare abstract class UniversalApplicationContainer<TProps extends IUniversalApplicationContainerProps> extends UniversalContainer<TProps> {
    static readonly defaultProps: IUniversalApplicationContainerProps;
    private static logger;
    private extraRoutes;
    private syncStateWithStorageTask;
    private storeUnsubscriber;
    /**
     * @stable - 23.04.2018
     * @param {TProps} props
     */
    constructor(props: TProps);
    /**
     * @stable [25.09.2019]
     */
    componentDidMount(): void;
    /**
     * @stable [24.09.2019]
     */
    componentWillUnmount(): void;
    /**
     * @stable [16.11.2019]
     * @param {RoutePredicateT} routePredicate
     * @returns {JSX.Element[]}
     */
    protected getRoutes(routePredicate?: RoutePredicateT): JSX.Element[];
    protected lookupConnectedContainerByRoutePath(path: string): IContainerCtor;
    protected registerRoute(container: IContainerCtor, config: IConnectorEntity): void;
    protected registerLogoutRoute(): void;
    protected onBeforeLogout(): void;
    protected isMessageVisible(): boolean;
    protected getErrorMessage(): string;
    /**
     * @stable [24.09.2019]
     */
    protected syncState(): void;
    /**
     * @stable [24.09.2019]
     */
    protected doSyncState(): void;
    /**
     * @stable [25.09.2019]
     */
    protected clearPreviousStates(): void;
    /**
     * @stable [24.09.2019]
     */
    protected registerStateTask(): boolean;
    /**
     * @stable [24.09.2019]
     */
    protected unregisterStateTask(): boolean;
    /**
     * @stable [16.11.2019]
     * @param {IContainerCtor} ctor
     * @param {IConnectorEntity} connectorEntity
     * @returns {JSX.Element}
     */
    protected abstract buildRoute(ctor: IContainerCtor, connectorEntity: IConnectorEntity): JSX.Element;
    /**
     *
     * @param {Map<IContainerCtor, IConnectorEntity>} map
     * @param {RoutePredicateT} routePredicate
     * @returns {JSX.Element[]}
     */
    private buildRoutes;
    /**
     * @stable [24.09.2019]
     * @returns {IStateSettings}
     */
    private readonly stateSettings;
}
