"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var base_1 = require("../../component/base");
var util_1 = require("../../util");
var definition_1 = require("../../definition");
var button_support_1 = require("./button.support");
var link_1 = require("../../component/link");
var Button = /** @class */ (function (_super) {
    __extends(Button, _super);
    function Button() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.buttonRef = React.createRef();
        return _this;
    }
    /**
     * @stable [27.01.2019]
     * @returns {JSX.Element}
     */
    Button.prototype.render = function () {
        var props = this.props;
        var buttonText = button_support_1.getButtonText(props);
        var hasContent = !R.isNil(props.children) || (!R.isNil(buttonText) && !R.isEmpty(buttonText));
        var hasIcon = button_support_1.hasIconButton(props);
        var className = util_1.joinClassName.apply(void 0, definition_1.DEFAULT_FLEX_BUTTON_CLASS_NAMES.concat([props.className,
            util_1.fullFlexClassName(props),
            hasContent ? 'rac-button-filled' : 'rac-button-not-filled',
            hasIcon ? 'rac-button-decorated' : 'rac-button-not-decorated',
            props.mini && 'rac-button-mini',
            props.outlined && 'rac-button-outlined',
            props.raised && 'rac-button-raised',
            this.isButtonRippled && this.uiFactory.rippleSurface]));
        if (props.to) {
            return (React.createElement(link_1.Link, { to: props.to, style: props.style, className: className }, buttonText));
        }
        var disabled = button_support_1.isButtonDisabled(props);
        return (React.createElement("button", __assign({ ref: this.buttonRef, type: props.type, title: props.title, style: props.style, className: className, disabled: disabled }, util_1.handlerPropsFactory(props.onClick, !disabled, props.touched)),
            hasIcon && this.uiFactory.makeIcon(button_support_1.getButtonIcon(props, 'spinner', 'error')),
            hasContent && (React.createElement("div", { className: 'rac-button-content' },
                buttonText && this.t(buttonText),
                props.children))));
    };
    /**
     * @stable [23.02.2019]
     */
    Button.prototype.blur = function () {
        this.buttonEl.blur(); // document.activeElement === body
    };
    Object.defineProperty(Button.prototype, "buttonEl", {
        /**
         * @stable [23.02.2019]
         * @returns {HTMLButtonElement}
         */
        get: function () {
            return this.buttonRef.current;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Button.prototype, "globalButtonSettings", {
        /**
         * @stable [23.02.2019]
         * @returns {IButtonProps}
         */
        get: function () {
            return util_1.ifNotNilThanValue(this.settings.components, function (components) { return components.button; }) || {};
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Button.prototype, "isButtonRippled", {
        /**
         * @stable [23.02.2019]
         * @returns {boolean}
         */
        get: function () {
            var props = this.props;
            return util_1.nvl(props.rippled, this.globalButtonSettings.rippled) !== false;
        },
        enumerable: true,
        configurable: true
    });
    Button.defaultProps = {
        type: 'button',
        full: false,
    };
    return Button;
}(base_1.BaseComponent));
exports.Button = Button;
//# sourceMappingURL=button.component.js.map