"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var util_1 = require("../../util");
var definitions_interface_1 = require("../../definitions.interface");
var definition_1 = require("../../definition");
/* @stable - 22.04.2018 */
exports.dictionariesMapper = function (storeEntity) { return ({
    dictionaries: __assign({}, storeEntity.dictionaries),
}); };
/* @stable - 16.04.2018 */
exports.transportMapper = function (storeEntity) { return ({
    transport: __assign({}, storeEntity.transport),
}); };
/**
 * @deprecated mapEditableEntity
 */
exports.formMapper = function (editableEntity) { return ({
    form: __assign({}, editableEntity),
}); };
/**
 * @stable [16.05.2018]
 * @param {IListEntity} listEntity
 * @param {IDataMutatorEntity} dataMutator
 * @returns {IListWrapperEntity}
 */
exports.listMapper = function (listEntity, dataMutator) {
    var list = __assign({}, listEntity);
    if (!R.isNil(dataMutator) && !R.isNil(list.data) && list.data.length > 0) {
        if (!R.isNil(dataMutator.sorter)) {
            list.data = R.sort(dataMutator.sorter, list.data);
        }
        if (!R.isNil(dataMutator.filter)) {
            list.totalCount = (list.data = R.filter(dataMutator.filter, list.data)).length;
        }
    }
    return { list: list };
};
/**
 * @deprecated Use mapPagedEntity
 * @param {IPaginatedEntity} entity
 * @returns {IPaginatedEntity}
 */
exports.listEntityPaginatedEntityMapper = function (entity) {
    return util_1.defValuesFilter({
        page: entity.page,
        pageSize: entity.pageSize,
        totalCount: entity.totalCount,
    });
};
/**
 * @deprecated Use mapListPagedEntity
 */
exports.listEntityPageEntityFilterMapper = function (listEntity, pageSize) {
    if (pageSize === void 0) { pageSize = definitions_interface_1.DEFAULT_PAGE_SIZE; }
    return ({
        page: listEntity.lockPage ? listEntity.page : definitions_interface_1.FIRST_PAGE,
        pageSize: pageSize,
    });
};
/**
 * @deprecated Use mapListWrapperPagedEntity
 */
exports.listEntityWrapperPageEntityFilterMapper = function (listEntity, pageSize) {
    if (pageSize === void 0) { pageSize = definitions_interface_1.DEFAULT_PAGE_SIZE; }
    return exports.listEntityPageEntityFilterMapper(listEntity.list, pageSize);
};
/**
 * @stable [30.01.2019]
 * @param {IListWrapperEntity} listWrapperEntity
 * @returns {IListEntity}
 */
exports.listSelector = function (listWrapperEntity) {
    return util_1.ifNotNilThanValue(listWrapperEntity, function () { return listWrapperEntity.list; });
};
/**
 * @deprecated Use mapListWrapperEntity
 */
exports.listWrapperMapper = function (listWrapperEntity, dataMutator) {
    return exports.listMapper(exports.listSelector(listWrapperEntity), dataMutator);
};
/**
 * @stable [31.08.2018]
 * @param {ITabPanelEntity} tabPanel
 * @returns {ITabPanelEntity}
 */
exports.tabPanelMapper = function (tabPanel) { return ({ tabPanel: __assign({}, tabPanel) }); };
/**
 * @stable [30.08.2018]
 * @param {ITabPanelWrapperEntity} tabPanelWrapperEntity
 * @returns {ITabPanelWrapperEntity}
 */
exports.tabPanelWrapperMapper = function (tabPanelWrapperEntity) {
    return exports.tabPanelMapper(tabPanelWrapperEntity.tabPanel);
};
/**
 * @deprecated Use selectChanges
 */
exports.editableEntityChangesSelector = function (entity) {
    return entity.changes;
};
/**
 * @deprecated Use mapExtendedEntity
 */
exports.entityMapper = function (entity, editableEntity) {
    return ({
        entity: __assign({}, entity, editableEntity && editableEntity.changes),
        entityId: util_1.orNull(entity, function () { return entity.id; }),
        originalEntity: __assign({}, entity),
        newEntity: R.isNil(entity) || R.isNil(entity.id),
    });
};
/**
 * @deprecated
 */
exports.selectedEntitySelector = function (listEntity) {
    return util_1.orNull(listEntity, function () { return listEntity.selected; });
};
/**
 * @deprecated Use selectListSelectedEntity
 */
exports.listSelectedEntitySelector = function (listWrapperEntity) {
    return util_1.ifNotNilThanValue(listWrapperEntity.list, function (list) { return exports.selectedEntitySelector(list); });
};
/**
 * @deprecated Use mapListSelectedExtendedEntity
 */
exports.listWrapperSelectedEntityMapper = function (listWrapperState, formEntity) {
    return exports.entityMapper(exports.listSelectedEntitySelector(listWrapperState), formEntity);
};
/**
 * @deprecated
 */
exports.actionsDisabledListEntityMapper = function (listEntity) { return ({
    actionsDisabled: listEntity.progress,
}); };
/**
 * @deprecated mapListWrapperActionsDisabled
 */
exports.actionsDisabledListWrapperEntityMapper = function (listWrapperEntity) {
    return exports.actionsDisabledListEntityMapper(listWrapperEntity.list);
};
/**
 * @deprecated selectEditableEntityToolbarToolsActiveFilter
 */
exports.toolbarActiveFilterToolEditableEntityMapper = function (editableEntity) {
    return R.isNil(editableEntity) || R.isEmpty(editableEntity.changes) ? [] : [definition_1.ToolbarToolsEnum.FILTER];
};
/**
 * @deprecated selectFormEntityToolbarToolsActiveFilter
 */
exports.toolbarActiveFilterToolFormWrapperEntityMapper = function (entityFormEntity) {
    return exports.toolbarActiveFilterToolEditableEntityMapper(entityFormEntity.form);
};
/**
 * @stable [29.05.2018]
 */
exports.universalDefaultMappers = [
    exports.transportMapper,
    util_1.mapUserWrapperEntity,
    exports.dictionariesMapper
];
//# sourceMappingURL=universal-connector.mapper.js.map