"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var react_day_picker_1 = require("react-day-picker");
var util_1 = require("../../../util");
var definition_1 = require("../../../definition");
var textfield_1 = require("../textfield");
var dialog_1 = require("../../dialog");
var layout_1 = require("../../layout");
var numberfield_1 = require("../numberfield");
var DateField = /** @class */ (function (_super) {
    __extends(DateField, _super);
    /**
     * @stable [07.01.2019]
     * @param {IDateFieldProps} props
     */
    function DateField(props) {
        var _this = _super.call(this, props) || this;
        _this.dialogRef = React.createRef();
        _this.onAccept = _this.onAccept.bind(_this);
        _this.onCalendarClick = _this.onCalendarClick.bind(_this);
        _this.onChangeYear = _this.onChangeYear.bind(_this);
        _this.defaultActions = [
            { type: definition_1.FieldActionTypesEnum.CALENDAR, onClick: _this.onCalendarClick }
        ].concat(_this.defaultActions);
        return _this;
    }
    /**
     * @stable [07.01.2018]
     * @param {DateTimeLikeTypeT} currentRawValue
     */
    DateField.prototype.onChangeManually = function (currentRawValue) {
        _super.prototype.onChangeManually.call(this, this.formatDate(currentRawValue));
    };
    DateField.prototype.getInputAttachmentElement = function () {
        var _this = this;
        var props = this.props;
        var state = this.state;
        var yearPlaceholder = props.yearPlaceholder;
        var settings = this.settings;
        return util_1.orNull(state.dialogOpened, function () {
            var initialDate = _this.dialogDate;
            return (React.createElement(dialog_1.Dialog, { ref: _this.dialogRef, acceptable: false, closable: false, className: 'rac-date-field-dialog' },
                React.createElement(layout_1.FlexLayout, { full: false },
                    React.createElement(numberfield_1.NumberField, { value: _this.state.year, onChange: _this.onChangeYear, pattern: '[0-9]{4}', mask: [/\d/, /\d/, /\d/, /\d/], placeholder: util_1.ifNotFalseThanValue(yearPlaceholder, function () { return util_1.nvl(yearPlaceholder, settings.messages.yearPlaceholderMessage.replace('{pattern}', settings.dateTime.yearPlaceholder)); }) })),
                React.createElement(react_day_picker_1.default, { firstDayOfWeek: props.firstDayOfWeek, fixedWeeks: true, locale: props.locale, month: initialDate, selectedDays: initialDate, onDayClick: _this.onAccept })));
        });
    };
    /**
     * @stable [07.01.2018]
     * @returns {Array<string | RegExp>}
     */
    DateField.prototype.getFieldMask = function () {
        var _this = this;
        return util_1.orNull(!this.hasDisplayValue, function () { return _super.prototype.getFieldMask.call(_this) || _this.dateTimeSettings.uiDateMask; });
    };
    /**
     * @stable [07.01.2019]
     * @returns {string}
     */
    DateField.prototype.getFieldPattern = function () {
        var _this = this;
        return util_1.orNull(!this.hasDisplayValue, function () { return _super.prototype.getFieldPattern.call(_this) || _this.dateTimeSettings.uiDatePattern; });
    };
    /**
     * @stable [07.01.2019]
     * @returns {string}
     */
    DateField.prototype.getFieldFormat = function () {
        return util_1.nvl(this.props.format, this.dateTimeSettings.uiDateFormat);
    };
    /**
     * @stable [07.01.2018]
     * @param {IBaseEvent} event
     */
    DateField.prototype.onClick = function (event) {
        _super.prototype.onClick.call(this, event);
        this.onCalendarClick();
    };
    /**
     * @stable [07.01.2019]
     * @param {AnyT} value
     * @returns {string}
     */
    DateField.prototype.decorateValueBeforeDisplaying = function (value) {
        return this.formatDate(value);
    };
    /**
     * @stable [02.05.2019]
     * @returns {string}
     */
    DateField.prototype.getFieldClassName = function () {
        return util_1.joinClassName(_super.prototype.getFieldClassName.call(this), 'rac-date-field');
    };
    /**
     * @stable [19.04.2019]
     * @param {number} value
     */
    DateField.prototype.onChangeYear = function (value) {
        var props = this.props;
        this.setState({ year: value });
        var date = new Date(this.dialogDate.getTime());
        date.setFullYear(value);
        if (this.dc.compare(date, props.minDate) >= 0
            && this.dc.compare(props.maxDate, date) >= 0) {
            this.onChangeManually(date);
        }
    };
    /**
     * @stable [24.02.2019]
     * @param {Date} currentTime
     */
    DateField.prototype.onAccept = function (currentTime) {
        this.onChangeManually(currentTime);
        this.dialog.onAccept();
        this.setState({ dialogOpened: false });
    };
    Object.defineProperty(DateField.prototype, "dialogDate", {
        /**
         * @stable [07.01.2019]
         * @returns {Date}
         */
        get: function () {
            if (this.isValueNotPresent) {
                return this.dc.getCurrentDate();
            }
            var dateValue = this.dc.tryConvertToDate(this.value, this.getFieldFormat());
            return dateValue instanceof Date
                ? dateValue
                : this.dc.getCurrentDate();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateField.prototype, "dialog", {
        /**
         * @stable [24.02.2019]
         * @returns {Dialog}
         */
        get: function () {
            return this.dialogRef.current;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateField.prototype, "dateTimeSettings", {
        /**
         * @stable [24.02.2019]
         * @returns {IDateTimeSettings}
         */
        get: function () {
            return this.settings.dateTime || {};
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [07.01.2019]
     * @param {DateTimeLikeTypeT} value
     * @returns {string}
     */
    DateField.prototype.formatDate = function (value) {
        return this.dc.format(value, this.getFieldFormat(), this.getFieldFormat());
    };
    /**
     * @stable [24.02.2019]
     */
    DateField.prototype.onCalendarClick = function () {
        var _this = this;
        this.setState({ dialogOpened: true }, function () { return _this.dialog.activate(); });
    };
    DateField.defaultProps = {
        autoOk: true,
        firstDayOfWeek: 1,
        preventFocus: true,
        minDate: new Date('01/01/1900'),
        maxDate: new Date('01/01/4000'),
    };
    return DateField;
}(textfield_1.BaseTextField));
exports.DateField = DateField;
//# sourceMappingURL=datefield.component.js.map