"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var ts_smart_logger_1 = require("ts-smart-logger");
var util_1 = require("../../../util");
var textfield_1 = require("../../field/textfield");
var menu_1 = require("../../menu");
var definition_1 = require("../../../definition");
var BaseSelect = /** @class */ (function (_super) {
    __extends(BaseSelect, _super);
    /**
     * @stable [15.09.2018]
     * @param {TProps} props
     */
    function BaseSelect(props) {
        var _this = _super.call(this, props) || this;
        _this.onSelect = _this.onSelect.bind(_this);
        _this.onClose = _this.onClose.bind(_this);
        _this.openMenu = _this.openMenu.bind(_this);
        _this.onFilterChange = _this.onFilterChange.bind(_this);
        if (props.expandActionRendered !== false) {
            _this.defaultActions = [
                { type: props.icon || definition_1.FieldActionTypesEnum.DROP_DOWN, onClick: _this.openMenu }
            ].concat(_this.defaultActions);
        }
        return _this;
    }
    /**
     * @stable [20.08.2018]
     * @param {Readonly<TProps extends IBaseSelectProps>} prevProps
     * @param {Readonly<TState extends IBasicSelectState>} prevState
     */
    BaseSelect.prototype.componentDidUpdate = function (prevProps, prevState) {
        _super.prototype.componentDidUpdate.call(this, prevProps, prevState);
        var props = this.props;
        if (this.state.needToOpenMenu && !R.isNil(props.options)) {
            this.showMenu();
            this.setState({ needToOpenMenu: false });
            if (props.onLoadDictionary) {
                props.onLoadDictionary(this.toFilteredOptions());
            }
        }
        /**
         * Need to reset the previous cached display value if the value has been cleared manually
         */
        if (!R.isNil(this.state.displayValue) && R.isNil(props.value)) {
            this.setState({ displayValue: null });
        }
    };
    BaseSelect.prototype.onKeyDown = function (event) {
        _super.prototype.onKeyDown.call(this, event);
        util_1.cancelEvent(event);
    };
    BaseSelect.prototype.onKeyBackspace = function (event) {
        _super.prototype.onKeyBackspace.call(this, event);
        this.clearValue();
    };
    BaseSelect.prototype.onKeyEnter = function (event) {
        _super.prototype.onKeyEnter.call(this, event);
        this.openMenu(event);
    };
    BaseSelect.prototype.onKeyEscape = function (event) {
        _super.prototype.onKeyEscape.call(this, event);
        if (this.menu.isOpen()) {
            this.hideMenu();
        }
    };
    /**
     * @stable [06.10.2018]
     */
    BaseSelect.prototype.clearValue = function () {
        _super.prototype.clearValue.call(this);
        this.setState({ displayValue: null });
    };
    /**
     * @stable [25.02.2019]
     * @param {IBaseEvent} event
     */
    BaseSelect.prototype.openMenu = function (event) {
        if (this.menu.isOpen() || this.state.needToOpenMenu) {
            return;
        }
        util_1.cancelEvent(event);
        var _a = this.props, onEmptyDictionary = _a.onEmptyDictionary, bindDictionary = _a.bindDictionary, options = _a.options, forceReload = _a.forceReload;
        var areOptionsEmpty = R.isNil(options);
        if (forceReload || areOptionsEmpty) {
            if (util_1.isFn(onEmptyDictionary)) {
                this.setState({ needToOpenMenu: true });
                onEmptyDictionary(bindDictionary);
            }
            else if (!areOptionsEmpty) {
                this.showMenu();
            }
        }
        else {
            this.showMenu();
        }
    };
    Object.defineProperty(BaseSelect.prototype, "inProgress", {
        /**
         * @stable [18.06.2018]
         * @returns {boolean}
         */
        get: function () {
            return util_1.inProgress(this.props) || !!this.state.needToOpenMenu;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [25.02.2019]
     * @param {IBaseEvent} event
     */
    BaseSelect.prototype.onClick = function (event) {
        _super.prototype.onClick.call(this, event);
        this.openMenu(event);
    };
    /**
     * @stable [01.06.2018]
     * @returns {JSX.Element}
     */
    BaseSelect.prototype.getInputAttachmentElement = function () {
        var _this = this;
        var props = this.props;
        return (React.createElement(menu_1.Menu, __assign({ ref: 'menu', width: function () { return util_1.getWidth(_this.getSelf()); }, options: this.toFilteredOptions(), onSelect: this.onSelect, onFilterChange: this.onFilterChange, onClose: this.onClose }, props.menuConfiguration)));
    };
    /**
     * @stable [20.08.2018]
     * @returns {ISelectOptionEntity[]}
     */
    BaseSelect.prototype.toFilteredOptions = function () {
        return this.options;
    };
    BaseSelect.prototype.getFieldClassName = function () {
        return util_1.joinClassName(_super.prototype.getFieldClassName.call(this), 'rac-base-select');
    };
    /**
     * @stable [29.06.2018]
     * @returns {AnyT}
     */
    BaseSelect.prototype.getEmptyValue = function () {
        var props = this.props;
        return util_1.isDef(props.emptyValue) ? props.emptyValue : this.settings.entityEmptyId;
    };
    /**
     * @stable [20.08.2018]
     * @param {ISelectOptionEntity} option
     */
    BaseSelect.prototype.onSelect = function (option) {
        this.onChangeManually(option.value);
        /**
         * We need to save a label because dictionary data may be refreshed
         * TODO Need to save an internal state in storage
         */
        this.setState({ displayValue: option.label || option.value });
        if (this.props.onSelect) {
            this.props.onSelect(option);
        }
    };
    /**
     * @stable [10.09.2019]
     */
    BaseSelect.prototype.onClose = function () {
        var props = this.props;
        if (util_1.isFn(props.onClose)) {
            props.onClose();
        }
    };
    /**
     * @stable [12.02.2019]
     * @param {AnyT} value
     * @returns {AnyT}
     */
    BaseSelect.prototype.getDecoratedValue = function (value) {
        var statedDisplayValue = this.state.displayValue;
        if (!R.isNil(statedDisplayValue)) {
            return _super.prototype.getDecoratedValue.call(this, statedDisplayValue, false);
        }
        var selectedItem = R.find(function (option) { return option.value === value; }, this.options);
        return R.isNil(selectedItem)
            ? _super.prototype.getDecoratedValue.call(this, value)
            : _super.prototype.getDecoratedValue.call(this, R.isNil(selectedItem.label)
                ? selectedItem.value
                : this.t(selectedItem.label), false);
    };
    Object.defineProperty(BaseSelect.prototype, "options", {
        /**
         * @stable [20.08.2018]
         * @returns {ISelectOptionEntity[]}
         */
        get: function () {
            return util_1.calc(this.props.options) || [];
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseSelect.prototype, "menu", {
        /**
         * @stable [20.08.2018]
         * @returns {IMenu}
         */
        get: function () {
            return this.refs.menu;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [20.08.2018]
     */
    BaseSelect.prototype.showMenu = function () {
        var filteredOptions = this.toFilteredOptions();
        if (filteredOptions.length) {
            this.menu.show();
        }
        else {
            BaseSelect.logger.debug('[$BasicSelect][showMenu] The options are empty. The menu does not show.');
        }
    };
    /**
     * @stable [20.08.2018]
     */
    BaseSelect.prototype.hideMenu = function () {
        this.menu.hide();
    };
    BaseSelect.prototype.onFilterChange = function (query) {
        var props = this.props;
        var onFilterChange = props.onFilterChange;
        var onDictionaryFilterChange = props.onDictionaryFilterChange;
        if (util_1.isFn(onFilterChange)) {
            onFilterChange(query);
        }
        if (util_1.isFn(onDictionaryFilterChange)) {
            onDictionaryFilterChange(props.bindDictionary, { payload: { query: query } });
        }
    };
    BaseSelect.logger = ts_smart_logger_1.LoggerFactory.makeLogger('BaseSelect');
    return BaseSelect;
}(textfield_1.BaseTextField));
exports.BaseSelect = BaseSelect;
//# sourceMappingURL=basic-select.component.js.map