"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var util_1 = require("../../util");
var router_1 = require("../../router");
var action_builder_1 = require("../../component/action.builder");
var di_1 = require("../../di");
var notification_1 = require("../../notification");
/**
 * @stable [04.10.2019]
 * @param {ISucceedRelatedFormMiddlewareConfigEntity} config
 * @returns {IEffectsAction[]}
 */
exports.makeSucceedRelatedFormEntityMiddleware = function (config) {
    if (config === void 0) { config = { navigateBack: true }; }
    var formSection = config.formSection, succeedMessage = config.succeedMessage, navigateBack = config.navigateBack;
    return [
        navigateBack === false && formSection
            ? action_builder_1.FormActionBuilder.buildSubmitDoneAction(formSection)
            : router_1.RouterActionBuilder.buildBackAction()
    ].concat((succeedMessage
        ? [notification_1.NotificationActionBuilder.buildInfoAction(di_1.getTranslator()(succeedMessage))]
        : []));
};
/**
 * @deprecated Use makeSucceedRelatedFormEntityMiddleware
 */
exports.makeSucceedRelatedFormMiddleware = function (config) {
    var formSection = config.formSection;
    var apiEntity = config.action.data;
    var parentEntity = config.getEntity(config.state);
    var relatedEntities = apiEntity.newEntity
        ? (config.getRelatedEntities(parentEntity) || []).concat(config.relatedEntity)
        : (config.getRelatedEntities(parentEntity) || []).map(function (anotherEntity) { return anotherEntity.id === config.relatedEntity.id ? config.relatedEntity : anotherEntity; });
    var changes = config.makeRelatedChanges(relatedEntities);
    var payloadWrapper = { payload: { id: parentEntity.id, changes: changes } };
    return util_1.ifNotNilThanValue(config.listSection, function (listSection) { return ([
        action_builder_1.ListActionBuilder.buildUpdateAction(listSection, payloadWrapper),
        config.navigateBack !== false
            ? router_1.RouterActionBuilder.buildBackAction()
            : action_builder_1.FormActionBuilder.buildSubmitDoneAction(formSection)
    ]); }, []).concat([
        notification_1.NotificationActionBuilder.buildInfoAction(di_1.getTranslator()(config.succeedMessage || di_1.staticInjector(di_1.DI_TYPES.Settings).messages.dataSaved))
    ]);
};
exports.makeSucceedListFormMiddleware = function (config) {
    var listSection = config.listSection, action = config.action, navigateBack = config.navigateBack, succeedMessage = config.succeedMessage;
    var connectorConfig = di_1.getDynamicSections().get(listSection);
    var dynamicListRoute = util_1.orNull(connectorConfig, function () { return connectorConfig.routeConfiguration.path; });
    var payloadWrapper = di_1.getModifyEntityPayloadFactory().makeInstance(action);
    return [
        action_builder_1.ListActionBuilder.buildMergeAction(listSection, payloadWrapper)
    ].concat((navigateBack !== false
        ? [router_1.RouterActionBuilder.buildReplaceAction(dynamicListRoute)]
        : [])).concat(notification_1.NotificationActionBuilder.buildInfoAction(di_1.staticInjector(di_1.DI_TYPES.Translate)(succeedMessage || di_1.staticInjector(di_1.DI_TYPES.Settings).messages.dataSaved)));
};
//# sourceMappingURL=succeed-form.middleware.js.map