"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var definitions_interface_1 = require("../definitions.interface");
var cond_1 = require("./cond");
var wrapper_1 = require("./wrapper");
var type_1 = require("./type");
var nvl_1 = require("./nvl");
var mapper_1 = require("./mapper");
/**
 * @stable [16.11.2019]
 * @param {IFormWrapperEntity<TEntity extends IEntity>} formWrapperEntity
 * @param {IGenericFieldEntity} fieldProps
 * @returns {AnyT}
 */
exports.getFormFieldValue = function (formWrapperEntity, fieldProps) {
    return type_1.isDef(fieldProps.value)
        ? fieldProps.value
        : (cond_1.ifNotEmptyThanValue(fieldProps.name, function (fieldName) { return cond_1.ifNotNilThanValue(R.isNil(formWrapperEntity.entity)
            ? cond_1.ifNotNilThanValue(formWrapperEntity.form, function (form) { return form.changes; })
            : formWrapperEntity.entity, function (data) { return Reflect.get(data, fieldName); }, definitions_interface_1.UNDEF_SYMBOL); }, definitions_interface_1.UNDEF_SYMBOL));
};
/**
 * @stable [16.11.2019]
 * @param {IFormWrapperEntity<TEntity extends IEntity>} formWrapperEntity
 * @param {IGenericFieldEntity} fieldProps
 * @returns {AnyT}
 */
exports.getFormFieldOriginalValue = function (formWrapperEntity, fieldProps) {
    return type_1.isDef(fieldProps.originalValue)
        ? fieldProps.originalValue
        : (cond_1.ifNotNilThanValue(formWrapperEntity.originalEntity, function (originalEntity) {
            return cond_1.ifNotEmptyThanValue(fieldProps.name, function (fieldName) { return Reflect.get(originalEntity, fieldName); }, definitions_interface_1.UNDEF_SYMBOL);
        }, definitions_interface_1.UNDEF_SYMBOL));
};
/**
 * @stable [25.09.2019]
 * @param {IFormEntity<TEntity>} entity
 * @returns {boolean}
 */
exports.isFormEntityDisabled = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.disabled === true || exports.isFormWrapperEntityInProgress(entity); }, false);
};
/**
 * @stable [25.10.2019]
 * @param {IFormEntity<TEntity extends IEntity>} entity
 * @returns {boolean}
 */
exports.isFormEntityValid = function (entity) {
    return wrapper_1.isValid(entity) && wrapper_1.isValid(mapper_1.selectEditableEntity(entity));
}; // Redux or auto validation
/**
 * @stable [25.10.2019]
 * @param {IFormWrapperEntity<TEntity extends IEntity>} entity
 * @returns {boolean}
 */
exports.isFormWrapperEntityInProgress = function (entity) {
    return wrapper_1.inProgress(mapper_1.selectEditableEntity(entity));
};
/**
 * @stable [25.09.2019]
 * @param {IGenericFormEntity} formEntity
 * @param {IGenericFieldEntity} fieldProps
 * @returns {boolean}
 */
exports.isFormFieldReadOnly = function (formEntity, fieldProps) {
    return nvl_1.nvl(cond_1.ifNotNilThanValue(fieldProps, function () { return fieldProps.readOnly; }), cond_1.ifNotNilThanValue(formEntity, function () { return formEntity.readOnly; })) === true;
};
//# sourceMappingURL=form.js.map