import { IEffectsAction } from 'redux-effects-promise';
import { IDictionaryEntity, IEditableEntity, IExtendedEntity, IFormWrapperEntity, ILifeCycleEntity, IListEntity, IListWrapperEntity, IOptionEntity, IPagedEntity, IPaginatedEntity, IPreviousActionWrapperEntity, IQueryFilterEntity, IQueryFilterWrapperEntity, ISelectOptionEntity, ISortDirectionEntity, ISortDirectionsEntity, ISortDirectionsWrapperEntity, ITransportEntity, ITransportWrapperEntity, IUserEntity, IUserWrapperEntity, ToolbarToolsEnum } from '../definition';
import { IActionsDisabledWrapper, IDisabledWrapper, IEntity, IEntityIdTWrapper, IKeyValue, IPreventEffectsWrapper, IProgressWrapper, IQueryWrapper, IRawDataWrapper, ISelectedWrapper, ITokenWrapper } from '../definitions.interface';
/**
 * @stable [17.11.2019]
 * @param {ITokenWrapper} entity
 * @returns {StringNumberT}
 */
export declare const selectToken: (entity: ITokenWrapper<string>) => string;
/**
 * @stable [17.11.2019]
 * @param {ITransportWrapperEntity} entity
 * @returns {string}
 */
export declare const selectTransportToken: (entity: ITransportWrapperEntity) => string;
/**
 * @stable [17.11.2019]
 * @param {ITransportWrapperEntity} entity
 * @returns {ITransportEntity}
 */
export declare const selectTransport: (entity: ITransportWrapperEntity) => ITransportEntity;
/**
 * @stable [20.10.2019]
 * @param {IEntityIdTWrapper} entity
 * @returns {EntityIdT}
 */
export declare const selectEntityId: (entity: IEntityIdTWrapper) => string | number;
/**
 * @stable [04.09.2019]
 * @param {IFormWrapperEntity<TEntity extends IEntity>} entity
 * @returns {IEditableEntity<TEntity extends IEntity>}
 */
export declare const selectEditableEntity: <TEntity extends IEntity = IEntity>(entity: IFormWrapperEntity<TEntity>) => IEditableEntity<TEntity>;
/**
 * @stable [04.09.2019]
 * @param {IEditableEntity} entity
 * @returns {TResult}
 */
export declare const selectChanges: <TResult extends IEntity = IEntity>(entity: IEditableEntity<IKeyValue>) => TResult;
/**
 * @stable [19.10.2019]
 * @param {IFormWrapperEntity} entity
 * @returns {TEntity}
 */
export declare const selectEditableEntityChanges: <TEntity extends IEntity = IEntity>(entity: IFormWrapperEntity<IEntity>) => TEntity;
/**
 * @stable [19.10.2019]
 * @param {IListWrapperEntity<TEntity extends IEntity>} entity
 * @returns {IListEntity<TEntity extends IEntity>}
 */
export declare const selectListEntity: <TEntity extends IEntity = IEntity>(entity: IListWrapperEntity<TEntity>) => IListEntity<TEntity, any>;
/**
 * @stable [18.10.2019]
 * @param {IListEntity} entity
 * @returns {ISortDirectionsEntity}
 */
export declare const selectListEntityDirections: (entity: IListEntity<IEntity, any>) => ISortDirectionsEntity;
/**
 * @stable [17.09.2019]
 * @param {ILifeCycleEntity} entity
 * @returns {boolean}
 */
export declare const selectLifeCycleEntityProgress: (entity: ILifeCycleEntity) => boolean;
/**
 * @stable [28.09.2019]
 * @param {IUserWrapperEntity} entity
 * @returns {IUserEntity}
 */
export declare const selectUserEntity: (entity: IUserWrapperEntity) => IUserEntity;
/**
 * @stable [04.09.2019]
 * @param {IQueryFilterWrapperEntity} entity
 * @returns {IQueryFilterEntity}
 */
export declare const selectQueryFilterEntity: (entity: IQueryFilterWrapperEntity) => IQueryFilterEntity;
/**
 * @stable [19.10.2019]
 * @param {IQueryWrapper} entity
 * @returns {string}
 */
export declare const selectQuery: (entity: IQueryWrapper<string>) => string;
/**
 * @stable [19.10.2019]
 * @param {ISelectedWrapper<TEntity extends IEntity>} listEntity
 * @returns {TEntity}
 */
export declare const selectSelectedEntity: <TEntity extends IEntity>(listEntity: ISelectedWrapper<TEntity>) => TEntity;
/**
 * @stable [19.10.2019]
 * @param {IEffectsAction} action
 * @returns {TEntity}
 */
export declare const selectSelectedEntityFromAction: <TEntity extends IEntity = IEntity>(action: IEffectsAction) => TEntity;
/**
 * @stable [20.10.2019]
 * @param {IPreviousActionWrapperEntity} data
 * @returns {IEffectsAction}
 */
export declare const selectPreviousAction: (data: IPreviousActionWrapperEntity) => IEffectsAction;
/**
 * @stable [20.10.2019]
 * @param {IEffectsAction} action
 * @returns {IEffectsAction}
 */
export declare const selectPreviousActionFromAction: (action: IEffectsAction) => IEffectsAction;
/**
 * @stable [20.10.2019]
 * @param {IEffectsAction} action
 * @returns {string}
 */
export declare const selectPreviousActionTypeFromAction: (action: IEffectsAction) => string;
/**
 * @stable [20.10.2019]
 * @param {IPreventEffectsWrapper} data
 * @returns {boolean}
 */
export declare const selectPreventEffects: (data: IPreventEffectsWrapper<boolean>) => boolean;
/**
 * @stable [20.10.2019]
 * @param {IEffectsAction} action
 * @returns {boolean}
 */
export declare const selectPreventEffectsFromAction: (action: IEffectsAction) => boolean;
/**
 * @stable [19.10.2019]
 * @param {IEffectsAction} action
 * @returns {TEntity}
 */
export declare const selectPayloadEntityFromAction: <TEntity extends IEntity = IEntity>(action: IEffectsAction) => TEntity;
/**
 * @stable [19.10.2019]
 * @param {IEffectsAction} action
 * @returns {TEntity}
 */
export declare const selectEntityFromAction: <TEntity extends IEntity = IEntity>(action: IEffectsAction) => TEntity;
/**
 * @stable [19.10.2019]
 * @param {IRawDataWrapper<TData>} listEntity
 * @returns {TData}
 */
export declare const selectListRawDataEntity: <TData = any>(listEntity: IRawDataWrapper<TData>) => TData;
/**
 * @stable [18.10.2019]
 * @param {IListWrapperEntity} listWrapperEntity
 * @returns {TData}
 */
export declare const selectListWrapperRawDataEntity: <TData = any>(listWrapperEntity: IListWrapperEntity<IEntity>) => TData;
/**
 * @stable [19.10.2019]
 * @param {IListWrapperEntity<TEntity extends IEntity>} listWrapperEntity
 * @returns {TEntity}
 */
export declare const selectListSelectedEntity: <TEntity extends IEntity>(listWrapperEntity: IListWrapperEntity<TEntity>) => TEntity;
/**
 * @stable [30.08.2019]
 * @param {IQueryFilterWrapperEntity} entity
 * @returns {string}
 */
export declare const selectFilterWrapperQuery: (entity: IQueryFilterWrapperEntity) => string;
/**
 * @stable [20.10.2019]
 * @param {EntityIdT} id
 * @returns {IEntityIdTWrapper}
 */
export declare const mapEntityId: (id: string | number) => IEntityIdTWrapper;
/**
 * @stable [13.11.2019]
 * @param {ISortDirectionsEntity} directions
 * @returns {ISortDirectionsWrapperEntity}
 */
export declare const mapSortDirectionsWrapperEntity: (directions: ISortDirectionsEntity) => ISortDirectionsWrapperEntity;
/**
 * @stable [20.10.2019]
 * @param {IEntityIdTWrapper} entity
 * @returns {IEntityIdTWrapper}
 */
export declare const mapIdentifiedEntity: (entity: IEntityIdTWrapper) => IEntityIdTWrapper;
/**
 * @stable [28.09.2019]
 * @param {IUserEntity} user
 * @returns {IUserWrapperEntity}
 */
export declare const mapUserEntity: (user: IUserEntity) => IUserWrapperEntity;
/**
 * @stable [12.10.2019]
 * @param {boolean} disabled
 * @returns {IDisabledWrapper}
 */
export declare const mapDisabled: (disabled: boolean) => IDisabledWrapper<boolean>;
/**
 * @stable [10.09.2019]
 * @param {string} query
 * @returns {IQueryWrapper}
 */
export declare const mapQuery: (query: string) => IQueryWrapper<string>;
/**
 * @stable [04.09.2019]
 * @param {IQueryFilterEntity} filter
 * @returns {IQueryFilterWrapperEntity}
 */
export declare const mapQueryFilterEntity: (filter: IQueryFilterEntity) => IQueryFilterWrapperEntity;
/**
 * @stable [04.09.2019]
 * @param {IEditableEntity<TEntity extends IEntity>} form
 * @returns {IFormWrapperEntity}
 */
export declare const mapEditableEntity: <TEntity extends IEntity = IEntity>(form: IEditableEntity<TEntity>) => IFormWrapperEntity<IEntity>;
/**
 * @stable [04.09.2019]
 * @param {IListEntity} list
 * @returns {IListWrapperEntity}
 */
export declare const mapListEntity: (list: IListEntity<IEntity, any>) => IListWrapperEntity<IEntity>;
/**
 * @stable [10.09.2019]
 * @param {IPagedEntity} entity
 * @returns {IPagedEntity}
 */
export declare const mapPagedEntity: (entity: IPagedEntity) => IPagedEntity;
/**
 * @stable [13.11.2019]
 * @param {ISortDirectionEntity} entity
 * @returns {ISortDirectionEntity}
 */
export declare const mapSortDirectionEntity: (entity: ISortDirectionEntity) => ISortDirectionEntity;
/**
 * @stable [04.10.2019]
 * @param {IListEntity} entity
 * @param {number} pageSize
 * @returns {IPagedEntity}
 */
export declare const mapListPagedEntity: (entity: IListEntity<IEntity, any>, pageSize?: number) => IPagedEntity;
/**
 * @stable [12.10.2019]
 * @param {IProgressWrapper} entity
 * @returns {IDisabledWrapper}
 */
export declare const mapDisabledProgressWrapper: (entity: IProgressWrapper) => IDisabledWrapper<boolean>;
/**
 * @stable [12.10.2019]
 * @param {IListWrapperEntity} listWrapperEntity
 * @returns {IDisabledWrapper}
 */
export declare const mapDisabledProgressListWrapperEntity: (listWrapperEntity: IListWrapperEntity<IEntity>) => IDisabledWrapper<boolean>;
/**
 * @stable [04.10.2019]
 * @param {IListWrapperEntity} entity
 * @param {number} pageSize
 * @returns {IPagedEntity}
 */
export declare const mapListWrapperPagedEntity: (entity: IListWrapperEntity<IEntity>, pageSize?: number) => IPagedEntity;
/**
 * @stable [10.09.2019]
 * @param {IPaginatedEntity} entity
 * @returns {IPaginatedEntity}
 */
export declare const mapPaginatedEntity: (entity: IPaginatedEntity) => IPaginatedEntity;
/**
 * @stable [04.09.2019]
 * @param {IListWrapperEntity} listWrapper
 * @returns {IListWrapperEntity}
 */
export declare const mapListWrapperEntity: (listWrapper: IListWrapperEntity<IEntity>) => IListWrapperEntity<IEntity>;
/**
 * @stable [28.09.2019]
 * @param {IUserWrapperEntity} userWrapper
 * @returns {IUserWrapperEntity}
 */
export declare const mapUserWrapperEntity: (userWrapper: IUserWrapperEntity) => IUserWrapperEntity;
/**
 * @stable [05.09.2019]
 * @param {TEntity} entity
 * @param {IEditableEntity} editableEntity
 * @returns {IExtendedEntity<TEntity extends IEntity>}
 */
export declare const mapExtendedEntity: <TEntity extends IEntity>(entity: TEntity, editableEntity?: IEditableEntity<IKeyValue>) => IExtendedEntity<TEntity>;
/**
 * @stable [06.09.2019]
 * @param {IListWrapperEntity} listWrapper
 * @param {IEditableEntity} editableEntity
 * @returns {IExtendedEntity<TEntity extends IEntity>}
 */
export declare const mapListSelectedExtendedEntity: <TEntity extends IEntity>(listWrapper: IListWrapperEntity<TEntity>, editableEntity?: IEditableEntity<IKeyValue>) => IExtendedEntity<TEntity>;
/**
 * @stable [04.09.2019]
 * @param {IQueryFilterWrapperEntity} queryFilter
 * @returns {IQueryFilterWrapperEntity}
 */
export declare const mapQueryFilterWrapperEntity: (queryFilter: IQueryFilterWrapperEntity) => IQueryFilterWrapperEntity;
/**
 * @stable [10.09.2019]
 * @param {IQueryFilterWrapperEntity} entity
 * @returns {IQueryWrapper}
 */
export declare const mapFilterWrapperQuery: (entity: IQueryFilterWrapperEntity) => IQueryWrapper<string>;
/**
 * @stable [17.09.2019]
 * @param {boolean} actionsDisabled
 * @returns {IActionsDisabledWrapper}
 */
export declare const mapActionsDisabled: (actionsDisabled: boolean) => IActionsDisabledWrapper;
/**
 * @stable [17.09.2019]
 * @param {IListEntity} list
 * @returns {IActionsDisabledWrapper}
 */
export declare const mapListActionsDisabled: (list: IListEntity<IEntity, any>) => IActionsDisabledWrapper;
/**
 * @stable [17.09.2019]
 * @param {IListWrapperEntity} listWrapper
 * @returns {}
 */
export declare const mapListWrapperActionsDisabled: (listWrapper: IListWrapperEntity<IEntity>) => IActionsDisabledWrapper;
/**
 * @stable [11.10.2019]
 * @param {TEntity[] | TEntity} data
 * @returns {Array<ISelectOptionEntity<TEntity extends IOptionEntity>>}
 */
export declare const mapSelectOptions: <TEntity extends IOptionEntity>(data: TEntity | TEntity[]) => ISelectOptionEntity<TEntity>[];
/**
 * @stable [18.09.2019]
 * @param {IEditableEntity} editableEntity
 * @returns {ToolbarToolsEnum[]}
 */
export declare const selectEditableEntityToolbarToolsActiveFilter: (editableEntity: IEditableEntity<IKeyValue>) => ToolbarToolsEnum[];
/**
 * @stable [18.09.2019]
 * @param {IFormWrapperEntity} entityFormEntity
 * @returns {ToolbarToolsEnum[]}
 */
export declare const selectFormEntityToolbarToolsActiveFilter: (entityFormEntity: IFormWrapperEntity<IEntity>) => ToolbarToolsEnum[];
/**
 * @stable [11.10.2019]
 * @param {IDictionaryEntity<TEntity>} dictionaryEntity
 * @param {(data: (TEntity[] | TEntity)) => TResult} accessor
 * @returns {TEntity[] | TEntity | TResult}
 */
export declare const mapDictionaryEntityData: <TEntity, TResult = TEntity | TEntity[]>(dictionaryEntity: IDictionaryEntity<TEntity>, accessor?: (data: TEntity | TEntity[]) => TResult) => TEntity | TResult | TEntity[];
/**
 * @stable [11.10.2019]
 * @param {IDictionaryEntity<TDictionaryEntity>} dictionaryEntity
 * @returns {Array<ISelectOptionEntity<TDictionaryEntity>>}
 */
export declare const mapDictionaryEntity: <TDictionaryEntity>(dictionaryEntity: IDictionaryEntity<TDictionaryEntity>) => ISelectOptionEntity<TDictionaryEntity>[];
