"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var cond_1 = require("./cond");
var type_1 = require("./type");
var calc_1 = require("./calc");
/**
 * @stable [24.10.2019]
 * @param {IValidWrapper} validEntity
 * @returns {boolean}
 */
exports.isValid = function (validEntity) {
    return cond_1.ifNotNilThanValue(validEntity, function () { return validEntity.valid !== false; }, false);
};
/**
 * @stable [24.10.2019]
 * @param {IPreventFocusWrapper} preventFocusEntity
 * @returns {boolean}
 */
exports.isFocusPrevented = function (preventFocusEntity) {
    return cond_1.ifNotNilThanValue(preventFocusEntity, function () { return preventFocusEntity.preventFocus === true; }, false);
};
/**
 * @stable [24.10.2019]
 * @param {IProgressWrapper} progressEntity
 * @returns {boolean}
 */
exports.inProgress = function (progressEntity) {
    return cond_1.ifNotNilThanValue(progressEntity, function () { return progressEntity.progress === true; }, false);
};
/**
 * @stable [24.10.2019]
 * @param {IUseKeyboardWrapper} useKeyboardEntity
 * @returns {boolean}
 */
exports.isKeyboardUsed = function (useKeyboardEntity) {
    return cond_1.ifNotNilThanValue(useKeyboardEntity, function () { return useKeyboardEntity.useKeyboard === true; }, false);
};
/**
 * @stable [25.10.2019]
 * @param {IVisibleWrapper} visibleEntity
 * @returns {boolean}
 */
exports.isVisible = function (visibleEntity) {
    return cond_1.ifNotNilThanValue(visibleEntity, function () { return visibleEntity.visible !== false; }, false);
};
/**
 * @stable [30.10.2019]
 * @param {IFocusedWrapper} wrapper
 * @returns {boolean}
 */
exports.isFocused = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.focused === true; }, false);
};
/**
 * @stable [26.10.2019]
 * @param {IHighlightOddWrapper} highlightOddEntity
 * @param {number} index
 * @returns {boolean}
 */
exports.isHighlightOdd = function (highlightOddEntity, index) {
    return cond_1.ifNotNilThanValue(highlightOddEntity, function () { return highlightOddEntity.highlightOdd !== false && (type_1.isNumber(index) ? calc_1.isOddNumber(index) : false); }, false);
};
/**
 * @stable [26.10.2019]
 * @param {IIndexedWrapper} indexedEntity
 * @returns {boolean}
 */
exports.isIndexed = function (indexedEntity) {
    return cond_1.ifNotNilThanValue(indexedEntity, function () { return indexedEntity.indexed === true; }, false);
};
/**
 * @stable [26.10.2019]
 * @param {IEditedWrapper} editedEntity
 * @returns {boolean}
 */
exports.isEdited = function (editedEntity) {
    return cond_1.ifNotNilThanValue(editedEntity, function () { return editedEntity.edited === true; }, false);
};
/**
 * @stable [26.10.2019]
 * @param {ISortableWrapper} sortableEntity
 * @returns {boolean}
 */
exports.isSortable = function (sortableEntity) {
    return cond_1.ifNotNilThanValue(sortableEntity, function () { return sortableEntity.sortable === true; }, false);
};
/**
 * @stable [27.10.2019]
 * @param {IDisabledWrapper} disabledEntity
 * @returns {boolean}
 */
exports.isDisabled = function (disabledEntity) {
    return cond_1.ifNotNilThanValue(disabledEntity, function () { return disabledEntity.disabled === true; }, false);
};
/**
 * @stable [27.10.2019]
 * @param {IDisabledWrapper} selectedWrapper
 * @returns {boolean}
 */
exports.isSelected = function (selectedWrapper) {
    return cond_1.ifNotNilThanValue(selectedWrapper, function () { return selectedWrapper.selected === true; }, false);
};
/**
 * @stable [27.10.2019]
 * @param {ISelectableWrapper} selectableWrapper
 * @returns {boolean}
 */
exports.isSelectable = function (selectableWrapper) {
    return cond_1.ifNotNilThanValue(selectableWrapper, function () { return selectableWrapper.selectable !== false; }, false);
};
/**
 * @stable [27.10.2019]
 * @param {IHoveredWrapper} hoveredWrapper
 * @returns {boolean}
 */
exports.isHovered = function (hoveredWrapper) {
    return cond_1.ifNotNilThanValue(hoveredWrapper, function () { return hoveredWrapper.hovered !== false; }, false);
};
/**
 * @stable [27.10.2019]
 * @param {IExpandActionRenderedWrapper} hoveredWrapper
 * @returns {boolean}
 */
exports.isExpandActionRendered = function (hoveredWrapper) {
    return cond_1.ifNotNilThanValue(hoveredWrapper, function () { return hoveredWrapper.expandActionRendered !== false; }, false);
};
/**
 * @stable [28.10.2019]
 * @param {IReadOnlyWrapper} readOnlyWrapper
 * @returns {boolean}
 */
exports.isReadOnly = function (readOnlyWrapper) {
    return cond_1.ifNotNilThanValue(readOnlyWrapper, function () { return readOnlyWrapper.readOnly === true; }, false);
};
/**
 * @stable [28.10.2019]
 * @param {IChangeableWrapper} changeableWrapper
 * @returns {boolean}
 */
exports.isChangeable = function (changeableWrapper) {
    return cond_1.ifNotNilThanValue(changeableWrapper, function () { return changeableWrapper.changeable !== false; }, false);
};
/**
 * @stable [28.10.2019]
 * @param {IKeyboardOpenWrapper} wrapper
 * @returns {boolean}
 */
exports.isKeyboardOpen = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.keyboardOpen === true; }, false);
};
/**
 * @stable [29.10.2019]
 * @param {IRequiredWrapper} wrapper
 * @returns {boolean}
 */
exports.isRequired = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.required === true; }, false);
};
/**
 * @stable [30.10.2019]
 * @param {ISyntheticCursorWrapper} wrapper
 * @returns {boolean}
 */
exports.isSyntheticCursorUsed = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.syntheticCursor !== false; }, false);
};
/**
 * @stable [12.11.2019]
 * @param {IEmptyOriginalValueWrapper} wrapper
 * @returns {boolean}
 */
exports.isEmptyOriginalValueSet = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.emptyOriginalValue === true; }, false);
};
/**
 * @stable [14.11.2019]
 * @param {IAlwaysReturnEmptyValueIfOriginalValueWrapper} wrapper
 * @returns {boolean}
 */
exports.isAlwaysReturnEmptyValueIfOriginalValue = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.alwaysReturnEmptyValueIfOriginalValue === true; }, false);
};
/**
 * @stable [13.11.2019]
 * @param {IMultiWrapper} wrapper
 * @returns {boolean}
 */
exports.isMulti = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.multi !== false; }, false);
};
//# sourceMappingURL=wrapper.js.map